okeeffe.all.show: Show all color palettes

Description Usage Arguments Value Examples

Description

Visually show all selected palettes from Georgia O'Keeffe's painting.

Usage

1

Arguments

name

Name of selected plaettes. Name can be a selected palette name or a vector of selected palette names: Black_Iris_II, Blue_and_Green_Music, Two_Pink_Shells. If omitted, all palette names will be used.

n

Color number of selected plaette. n should be larger than 1 and smaller than the maximum color number of the specific palette. If omitted, the maximum color number of the specific palette will be used.

Value

An image showing a specific plaette.

Examples

1
2
3
okeeffe.all.show()
okeeffe.all.show("Blue_and_Green_Music", 4)
okeeffe.all.show(c("Black_Iris_II", "Two_Pink_Shells"), 3)

RickWeng/OKeeffeColor documentation built on June 1, 2019, 12:48 p.m.