Description Usage Arguments Value Examples
Get color hex of a specific plaette from Georgia O'Keeffe's painting.
1 | okeeffe.col(name, n = NULL)
|
name |
Name of a specific plaette. Name can be one of the following: |
n |
Color number of a specific plaette. n should be larger than 1 and smaller than the maximum color number of the specific palette. If omitted, the maximum color number of the specific palette will be used. |
A vector of hex color codes.
1 2 3 | okeeffe.col("Blue_and_Green_Music")
okeeffe.col("Black_Iris_II", 3)
okeeffe.col("Two_Pink_Shells", 2)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.