okeeffe.col.show: Show a specific color palette

Description Usage Arguments Value Examples

Description

Visually show a specific color palette from Georgia O'Keeffe's painting.

Usage

1

Arguments

name

Name of a specific plaette. Name can be one of the following: Black_Iris_II, Blue_and_Green_Music, Two_Pink_Shells.

n

Color number of a specific plaette. n should be larger than 1 and smaller than the maximum color number of the specific palette. If omitted, the maximum color number of the specific palette will be used.

Value

An image showing a specific plaette.

Examples

1
2
3
okeeffe.col.show("Blue_and_Green_Music")
okeeffe.col.show("Black_Iris_II", 3)
okeeffe.col.show("Two_Pink_Shells", 2)

RickWeng/OKeeffeColor documentation built on June 1, 2019, 12:48 p.m.