Description Usage Arguments Value Examples
Visually show all selected palettes from Georgia O'Keeffe's painting.
1 | okeeffe.all.show(name = NULL, n = NULL)
|
name |
Name of selected plaettes. Name can be a selected palette name or a vector of selected palette names: |
n |
Color number of selected plaette. n should be larger than 1 and smaller than the maximum color number of the specific palette. If omitted, the maximum color number of the specific palette will be used. |
An image showing a specific plaette.
1 2 3 | okeeffe.all.show()
okeeffe.all.show("Blue_and_Green_Music", 4)
okeeffe.all.show(c("Black_Iris_II", "Two_Pink_Shells"), 3)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.