Description Usage Arguments Value Examples
Visually show a specific color palette from Georgia O'Keeffe's painting.
1 | okeeffe.col.show(name, n = NULL)
|
name |
Name of a specific plaette. Name can be one of the following: |
n |
Color number of a specific plaette. n should be larger than 1 and smaller than the maximum color number of the specific palette. If omitted, the maximum color number of the specific palette will be used. |
An image showing a specific plaette.
1 2 3 | okeeffe.col.show("Blue_and_Green_Music")
okeeffe.col.show("Black_Iris_II", 3)
okeeffe.col.show("Two_Pink_Shells", 2)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.